@@ -2,11 +2,12 @@
 #'
 #' @description Computes comorbidity scores such as the weighted Charlson score and the Elixhauser comorbidity score.
 #'
-#' @param x A tidy data frame with one column containing an individual ID and a column containing all diagnostic codes.
+#' @param x A tidy `data.frame` (or a `data.table`; `tibble`s are supported too) with one column containing an individual ID and a column containing all diagnostic codes.
+#' Extra columns other than ID and codes are discarded.
+#' Column names must be syntactically valid names, otherwise they are forced to be so by calling the [make.names()] function.
 #' @param id Column of `x` containing the individual ID.
 #' @param code Column of `x` containing diagnostic codes. Codes must be in upper case with no punctuation in order to be properly recognised.
 #' @param score The comorbidity score to compute. Possible choices are the weighted Charlson score (`charlson`) and the weighted Elixhauser score (`elixhauser`). Values are case-insensitive.
-#' @param icd The version of ICD coding to use. Possible choices are ICD-9-CM (`icd9`) or ICD-10 (`icd10`). Defaults to `icd10`, and values are case-insensitive.
 #' @param assign0 Apply a hierarchy of comorbidities. If `TRUE`, should a comorbidity be present in a patient with different degrees of severity, then the milder form will be assigned to 0 and therefore not counted. By doing this, a type of comorbidity is not counted more than once in each patient. In particular, the comorbidities that are affected by this argument are:
 #' * "Mild liver disease" (`mld`) and "Moderate/severe liver disease" (`msld`) for the Charlson score;
 #' * "Diabetes" (`diab`) and "Diabetes with complications" (`diabwc`) for the Charlson score;
@@ -14,6 +15,7 @@
 #' * "Hypertension, uncomplicated" (`hypunc`) and "Hypertension, complicated" (`hypc`) for the Elixhauser score;
 #' * "Diabetes, uncomplicated" (`diabunc`) and "Diabetes, complicated" (`diabc`) for the Elixhauser score;
 #' * "Solid tumour" (`solidtum`) and "Metastatic cancer" (`metacanc`) for the Elixhauser score.
+#' @param icd The version of ICD coding to use. Possible choices are ICD-9-CM (`icd9`) or ICD-10 (`icd10`). Defaults to `icd10`, and values are case-insensitive.
 #' @param factorise Return comorbidities as factors rather than numeric, where (1 = presence of comorbidity, 0 = otherwise). Defaults to `FALSE`.
 #' @param labelled Attach labels to each comorbidity, compatible with the RStudio viewer via the [utils::View()] function. Defaults to `TRUE`.
 #' @param tidy.codes Tidy diagnostic codes? If `TRUE`, all codes are converted to upper case and all non-alphanumeric characters are removed using the regular expression \code{[^[:alnum:]]}. Defaults to `TRUE`.
@@ -110,11 +112,11 @@
 #' comorbidity(x = x, id = "id", code = "code", score = "elixhauser", assign0 = FALSE)
 #' @export
 
-comorbidity <- function(x, id, code, score, icd = "icd10", assign0, factorise = FALSE, labelled = TRUE, tidy.codes = TRUE) {
+comorbidity <- function(x, id, code, score, assign0, icd = "icd10", factorise = FALSE, labelled = TRUE, tidy.codes = TRUE) {
   ### Check arguments
   arg_checks <- checkmate::makeAssertCollection()
-  # x must be a data.frame
-  checkmate::assert_data_frame(x, add = arg_checks)
+  # x must be a data.frame (or a data.table)
+  checkmate::assert_true(all(class(x) %in% c("data.frame", "data.table", "tbl", "tbl_df")), add = arg_checks)
   # id, code, score, icd must be a single string value
   checkmate::assert_string(id, add = arg_checks)
   checkmate::assert_string(code, add = arg_checks)
@@ -131,6 +133,19 @@ comorbidity <- function(x, id, code, score, icd = "icd10", assign0, factorise =
   checkmate::assert_logical(factorise, len = 1, add = arg_checks)
   checkmate::assert_logical(labelled, len = 1, add = arg_checks)
   checkmate::assert_logical(tidy.codes, len = 1, add = arg_checks)
+  # force names to be syntactically valid:
+  if (any(names(x) != make.names(names(x)))) {
+    names(x) <- make.names(names(x))
+    warning("Names of the input dataset 'x' have been modified by make.names(). See ?make.names() for more details.", call. = FALSE)
+  }
+  if (id != make.names(id)) {
+    id <- make.names(id)
+    warning("The input 'id' string has been modified by make.names(). See ?make.names() for more details.", call. = FALSE)
+  }
+  if (code != make.names(code)) {
+    code <- make.names(code)
+    warning("The input 'id' string has been modified by make.names(). See ?make.names() for more details.", call. = FALSE)
+  }
   # id, code must be in x
   checkmate::assert_subset(id, choices = names(x), add = arg_checks)
   checkmate::assert_subset(code, choices = names(x), add = arg_checks)
@@ -144,7 +159,11 @@ comorbidity <- function(x, id, code, score, icd = "icd10", assign0, factorise =
   regex <- lofregex[[score]][[icd]]
 
   ### Subset only 'id' and 'code' columns
-  x <- x[, c(id, code)]
+  if (data.table::is.data.table(x)) {
+    x <- x[, c(id, code), with = FALSE]
+  } else {
+    x <- x[, c(id, code)]
+  }
 
   ### Turn x into a DT
   data.table::setDT(x)
